@@ -22,11 +22,14 @@ from turberfield.catchphrase.render import Action
 from turberfield.catchphrase.render import Parameter
 from turberfield.catchphrase.render import Renderer
 from turberfield.catchphrase.render import Settings
+from turberfield.dialogue.types import DataObject
 
 
-class Story(Renderer):
+class Story(Renderer, DataObject):
 
     def __init__(self, cfg=None, **kwargs):
+        super().__init__(**kwargs)
+
         self.definitions = {
             "catchphrase-colour-washout": "hsl(50, 0%, 100%, 1.0)",
             "catchphrase-colour-shadows": "hsl(202.86, 100%, 4.12%)",
@@ -42,8 +45,8 @@ class Story(Renderer):
     @property
     def actions(self):
         yield Action(
-            "cmd", None, "/drama/cmd/", [], "post",
-            [Parameter("cmd", True, self.context.validator, [self.context.prompt], ">")],
+            "cmd", None, "/{0.id.hex}/cmd/", [self], "post",
+            [Parameter("cmd", False, self.context.validator, [self.context.prompt], ">")],
             "Enter"
         )
 
