@@ -19,7 +19,6 @@
 
 import unittest
 
-from balladeer import Gesture
 from balladeer import Phrase
 from balladeer import Name
 from balladeer import Named
@@ -35,18 +34,6 @@ class NamedTests(unittest.TestCase):
         self.assertIn("Mug", str(mug))
 
 
-class GestureTests(unittest.TestCase):
-
-    def test_simple(self):
-        g = Gesture(phrases=[
-            Phrase(Verb("make"), Name("tea")),
-            Phrase(Verb("make"), Name("brew")),
-        ])
-        self.assertIn("make tea", str(g))
-        self.assertIn("\n", str(g))
-        self.assertIn("make brew", str(g))
-
-
 class VerbTests(unittest.TestCase):
 
     def test_simple(self):
